enum.fi


domain

Summary

enum.fi is a domain controlled by two nameservers at ficora.fi. They are on the same IP network. Incoming mail for enum.fi is handled by one mailserver also at ficora.fi. e164.fi cnames to this hostname. whois.fi and tietoturvaopas.fi share both nameservers and mailservers with this domain. e164.fi, govcert.fi, natsakerhet.fi, onlinesafety.fi, natsakerhetsskola.fi and at least seven other hosts share nameservers with this domain. cert.fi, ficora.fi and viestintavirasto.fi share mailservers with this domain. www.enum.fi are subdomains to this hostname. Reputation is not yet known.



Buy

Similar domains for sale:enum.dk, enum.mn, enum.la, enum.im, enum.tk( 4000 EUR), enum.be, enum.nu, enum.gd, enum.sg, enum.vc,

DNS Records

baserecordnameipreverserouteas
enum.fins-soa ns1.ficora.fi87.239.124.30
Finland
(none) 87.239.120.0/21
FI-FICORA
AS39662
FI-FICORA-AS Finnish Communications Regulatory Authority
ns ns1.ficora.fi87.239.124.30
Finland
(none)
ns2.ficora.fi87.239.124.59
Finland
mx 10mail.ficora.fi194.100.96.25
Finland
194.100.0.0/16
TDC Song Oy
AS3292
TDC Data Networks TDC A/S
fins-soa a.fi193.166.4.1
Finland
tld.ficora.fi193.166.0.0/15
FUNET-BLOCK
AS1741
FUNETAS FUNET autonomous system
ns a.fi193.166.4.1
Finland
tld.ficora.fi
b.fi194.146.106.26
Sweden
fi1.dnsnode.net194.146.106.0/24
NETNOD-DB-LAN-GBG $Id: route:194.146.106.0-24,v 1.2 2004/08/18 11:41:41 liman Exp $
AS8674
NETNOD-IX Netnod Internet Exchange Sverige AB (former D-GIX) $Id: aut-num: ,v 1.12 2008/07/01 12:56:12 liman Exp $
c.fi128.214.4.29
Finland
hydra.helsinki.fi128.214.0.0/16
FUNET
AS1741
FUNETAS FUNET autonomous system
d.fi77.72.229.253
Sweden
77.72.224.0/21
$Id: route:77.72.224.0-21,v 1.1 2009-03-18 11:04:20 liman Exp $
AS8674
NETNOD-IX Netnod Internet Exchange Sverige AB (former D-GIX) $Id: aut-num: ,v 1.12 2008/07/01 12:56:12 liman Exp $
e.fi194.0.1.14
United Kingdom
194.0.1.0/24
ICB
AS42909
COMMUNITYDNS Community DNS Internet Computer Bureau Ltd
f.fi87.239.127.198
Finland
87.239.120.0/21
FI-FICORA
AS39662
FI-FICORA-AS Finnish Communications Regulatory Authority
ficora.fi   net   helsinki.fi   dnsnode.net  

Thumbnails powered by Thumbshots

graph

dot

shared

hostnames pointing here by cname

e164.fi


nameservers used by this domain

ns1.ficora.fi
ns2.ficora.fi

ip numbers of nameservers

87.239.124.30
87.239.124.59


mailservers used by this domain

mail.ficora.fi(primary)

ip numbers of mailservers

194.100.96.25

reverse names of the mailservers

mail.ficora.fi


subdomains

www.enum.fi


hostnames pointing here by cname
 mailservers used by this domain
  domains sharing mailservers
   domains sharing nameservers
    reverse names of the mailservers
e164.fiX  X  
mail.ficora.fi X  X 
tietoturvaopas.fi  XX  
whois.fi  XX  

whois

...

blacklists

...

analysis

...

contact

...

alternatives: wml, rss (beta)

random
date20091222 rtsakmarka rtsakmark3