enum.nl


domain

Summary

enum.nl is a domain controlled by three nameservers. Two of them are on the same IP network. Incoming mail for enum.nl is handled by one mailserver at sidn.nl. nic.nl, sidn.nl, domjur.nl and enuminnederland.nl share both nameservers and mailservers with this domain. aw, dns.nl, iana.nl, icann.nl, nlnet.nl and at least eleven other hosts share nameservers with this domain. www.sidn.nl share mailservers with this domain. eto.enum.nl, ns1.enum.nl, ers.enum.nl, testbu.enum.nl, postmaster.enum.nl and at least one other host are subdomains to this hostname. Reputation is not yet known.



Buy

Similar domains for sale:enum.dk, enum.mn, enum.la, enum.im, enum.tk( 4000 EUR), enum.be, enum.nu, enum.gd, enum.sg, enum.vc,

DNS Records

baserecordnameipreverserouteas
enum.nlns-soa ns1.enum.nl193.176.144.8
Netherlands
193.176.144.0/24
Stichting Internet Domeinregistratie Nederland
AS1140
SIDN Stichting Internet Domeinregistratie Nederland
ns ns2.sidn.nl194.171.17.5
Netherlands
194.171.17.0/24
AS1103
SURFNET-NL SURFnet, The Netherlands
ns3.domain-registry.nl193.176.144.6
Netherlands
e.ext.nic.fr193.176.144.0/24
Stichting Internet Domeinregistratie Nederland
AS1140
SIDN Stichting Internet Domeinregistratie Nederland
 -
ns1.enum.nl193.176.144.8
Netherlands
mx 10kamx.sidn.nl94.198.152.69
Netherlands
94.198.152.0/21
NL-SIDN
nlns-soa ns1.nic.nl193.176.144.2
Netherlands
193.176.144.0/24
Stichting Internet Domeinregistratie Nederland
ns sns-pb.isc.org192.5.4.1
United States
192.5.4.0/24
ISC
AS3557
ISC-CALIFORNIA Internet Systems Consortium, Inc.
ns1.nic.nl193.176.144.2
Netherlands
193.176.144.0/24
Stichting Internet Domeinregistratie Nederland
AS1140
SIDN Stichting Internet Domeinregistratie Nederland
ns3.nic.nl194.171.17.2
Netherlands
194.171.17.0/24
AS1103
SURFNET-NL SURFnet, The Netherlands
ns2.nic.nl213.154.241.28
Netherlands
213.154.224.0/19
BIT B.V.
AS12859
NL-BIT BV Ede, The Netherlands
ns-nl.nic.fr192.93.0.4
France
ns2.nic.fr192.93.0.0/24
NIC-FR-DNS-SITE-ST-QUENTIN
AS2485
NIC-FR-SITE-SQY AFNIC FR
ns4.nic.nl62.4.86.232
Europe
62.4.86.0/24
AS6461
MFNX MFN - Metromedia Fiber Network
nl1.dnsnode.net194.146.106.42
Sweden
194.146.106.0/24
NETNOD-DB-LAN-GBG $Id: route:194.146.106.0-24,v 1.2 2004/08/18 11:41:41 liman Exp $
AS8674
NETNOD-IX Netnod Internet Exchange Sverige AB (former D-GIX) $Id: aut-num: ,v 1.12 2008/07/01 12:56:12 liman Exp $
nic.nl   sidn.nl   fr   nic.fr   domain-registry.nl   dnsnode.net   net   org   isc.org   ext.nic.fr  

Thumbnails powered by Thumbshots

graph

dot

shared

nameservers used by this domain

ns1.enum.nl
ns2.sidn.nl
ns3.domain-registry.nl

other names of the nameservers

e.ext.nic.fr

domains sharing nameservers under another name

fr
pm
re
tf
wf
yt


mailservers used by this domain

kamx.sidn.nl(primary)

ip numbers of mailservers

94.198.152.69

reverse names of the mailservers

kamx.sidn.nl



mailservers used by this domain
 domains sharing mailservers
  nameservers used by this domain
   other names of the nameservers
    domains sharing nameservers
     reverse names of the mailservers
      reverse names of the nameservers
       reverse of ns in soa
        ns in soa
         subdomains
ns1.enum.nl  X   XXXX 
domjur.nl X  X      
e.ext.nic.fr   X  X    
enuminnederland.nl X  X      
kamx.sidn.nlX    X     
nic.nl X  X      
ns2.sidn.nl  X   X    
ns3.domain-registry.nl  X   X    
sidn.nl X  X      

whois

...

blacklists

...

analysis

...

contact

...

alternatives: wml, rss (beta)

random
date20091127 rtsakmarka rtsakmark2