fn.hu


Domain

Summary

fn.hu is a domain controlled by two nameservers on different IP networks. Incoming mail for fn.hu is handled by one mailserver at sanomaonline.hu. fn.hu has one IP number , but the reverse is fe02.ew.sanomabp.hu. fhm.hu and figyelo.hu point to the same IP and also shares both nameservers and mailservers. focivb2006.hu point to the same IP and also shares mailservers. www.fn.hu, www.fhm.hu and fe02.ew.sanomabp.hu point to the same IP. mc.hu, ekh.hu, nlc.hu, lap.hu, polc.hu and at least 39 other hosts share both nameservers and mailservers with this domain. exit.hu, best.hu, story.hu, vnubp.hu, tango.hu and at least 55 other hosts share nameservers with this domain. nl.hu, ng.hu, nle.hu, best.hu, tv24.hu and at least 68 other hosts share mailservers with this domain. www.fn.hu, mail.fn.hu and valkyre.fn.hu are subdomains to this hostname. fn.hu is hosted on a server in Hungary. Reputation is not yet known.



Buy

Similar domains for sale:fn.cc, fn.tj, fn.cn, f-n.es, f-n.it( 1150 EUR), f-n.su, f-n.ca, f-n.biz, f-n.net( 8588 USD), f-n.info,

DNS Records

BaseRecordNameIPReverseRouteAS
fn.hua 193.68.35.122
Hungary
fe02.ew.sanomabp.hu193.68.32.0/19
INVITEL Zrt.
AS12301
INVITEL , Hungary
ns-soa d0.ew.sanomabp.hu81.0.66.204
Hungary
81.0.64.0/18
INVITEL Zrt.
ns ns2.sanomaonline.hu195.70.38.236
Hungary
stream.sanomabp.hu195.70.32.0/19
InterWare Inc. HU
AS8358
INTERWARE-AS InterWare Autonomus System Hungary
d0.ew.sanomabp.hu81.0.66.204
Hungary
81.0.64.0/18
INVITEL Zrt.
AS12301
INVITEL , Hungary
mx 10mail.sanomaonline.hu195.70.36.71
Hungary
195.70.32.0/19
InterWare Inc. HU
AS8358
INTERWARE-AS InterWare Autonomus System Hungary
huns-soa ns.nic.hu193.239.148.62
Hungary
193.239.148.0/24
Council of Hungarian Internet Providers (ISZT) 1132 Budapest Victor Hugo u. 18-22. HU
AS12303
ISZT-AS Council of Hungarian Internet Providers (ISZT) 1132 Budapest Victor Hugo u. 18-22.
ns ns-com.nic.hu194.0.1.12
United Kingdom
194.0.1.0/24
ICB
AS42909
COMMUNITYDNS Community DNS Internet Computer Bureau Ltd
ns-se.nic.hu77.72.229.251
Sweden
hu1.dnsnode.net77.72.224.0/21
$Id: route:77.72.224.0-21,v 1.1 2009-03-18 11:04:20 liman Exp $
AS8674
NETNOD-IX Netnod Internet Exchange Sverige AB (former D-GIX) $Id: aut-num: ,v 1.12 2008/07/01 12:56:12 liman Exp $
ns.nic.hu193.239.148.62
Hungary
193.239.148.0/24
Council of Hungarian Internet Providers (ISZT) 1132 Budapest Victor Hugo u. 18-22. HU
AS12303
ISZT-AS Council of Hungarian Internet Providers (ISZT) 1132 Budapest Victor Hugo u. 18-22.
ns1.nic.hu193.239.149.3
Hungary
193.239.149.0/24
Council of Hungarian Internet Providers (ISZT) 1132 Budapest Victor Hugo u. 18-22. HU
ns2.nic.hu193.6.16.1
Hungary
193.6.0.0/16
HBONE/HUNGARNET Block 01
AS1955
HBONE-AS HUNGARNET Hungarian Academic and Research Network National Information Infrastructure Development Program H-1132 Budapest Victor Hugo street 18-22 Hungary
ns3.nic.hu195.70.35.250
Hungary
195.70.32.0/19
InterWare Inc. HU
AS8358
INTERWARE-AS InterWare Autonomus System Hungary
ns2.nic.fr192.93.0.4
France
192.93.0.0/24
NIC-FR-DNS-SITE-ST-QUENTIN
AS2485
NIC-FR-SITE-SQY AFNIC FR
nic.hu   sanomabp.hu   ew.sanomabp.hu   sanomaonline.hu   fr   nic.fr   dnsnode.net   net  

Thumbnails powered by Thumbshots

Graph

dot

Shared

ip numbers of host

193.68.35.122

ptrs of ip numbers

fe02.ew.sanomabp.hu

ip numbers using ptr to this host

81.0.75.35


nameservers used by this domain

d0.ew.sanomabp.hu
ns2.sanomaonline.hu

ip numbers of nameservers

195.70.38.236
81.0.66.204

reverse names of the nameservers

d0.ew.sanomabp.hu
stream.sanomabp.hu

other names of the nameservers

ew.sanomabp.hu
stream.sanomabp.hu


mailservers used by this domain

mail.sanomaonline.hu(primary)

ip numbers of mailservers

195.70.36.71

reverse names of the mailservers

mail.sanomaonline.hu

domains sharing mailservers under another name

marieclaire.hu
starttartalom.com
tesz-vesz.hu



hostnames sharing ip with a-records
 mailservers used by this domain
  other names of the mailservers
   domains sharing mailservers
    domains sharing mailservers under another name
     nameservers used by this domain
      other names of the nameservers
       domains sharing nameservers
        ptrs of ip numbers
         reverse names of the mailservers
          reverse names of the nameservers
           reverse of ns in soa
            ns in soa
             subdomains
fhm.huX  X   X       
figyelo.huX  X   X       
starttartalom.com  X X  X       
*.fn.huX            X 
advent.hu   X   X       
best.hu   X   X       
cosmopolitan.hu   X   X       
d0.ew.sanomabp.hu     X    XXX  
ekh.hu   X   X       
fakanal.hu   X   X       
fe02.ew.sanomabp.huX       X      
filmgyar.com   X   X       
fitnet.hu   X   X       
fntudosito.hu   X   X       
focivb2006.huX  X           
geographic.hu   X   X       
hirstart.hu   X   X       
hotdog.hu   X   X       
hotgames.hu   X   X       
ingyentartalom.com   X   X       
kirakat.hu   X   X       
kismama.hu   X   X       
lap.hu   X   X       
lapkereso.hu   X   X       
lapklub.hu   X   X       
mail.sanomaonline.hu X       X     
maximanet.hu   X   X       
mc.hu   X   X       
meglepetes.hu   X   X       
mobilstart.hu   X   X       
nlc.hu   X   X       
noklapja.hu   X   X       
noklapja.net   X   X       
pdamania.hu   X   X       
polc.hu   X   X       
praktika.hu   X   X       
sanomaonline.hu   X   X       
startapro.hu   X   X       
startartalom.com  X    X       
startaukcio.hu   X   X       
startlap.com   X   X       
startlap.hu   X   X       
startlapjatekok.hu   X   X       
story.hu   X   X       
stream.sanomabp.hu      X   X    
szrtv.hu   X   X       
tango.hu   X   X       
terkep24.com   X   X       
tesz-vesz.com   X   X       
teszvesz.com   X   X       
tvfilm.hu   X   X       
valkyre.fn.hu  X          X 
valkyre.sanomabp.hu  XX           
vezess.hu   X   X       
vnubp.hu   X   X       
www.fn.huX            X 
zsebtv.com   X   X       

Whois

Whois information is fetched in the background

Blacklists

Blacklist information is fetched in the background

Analysis

Analysis is performed in the background

Contact

Contact information is fetched in the background

alternatives: wml, rss (beta)

random
date20100105 rtsakmarka rtsakmark8