Summary
fn.no is a domain controlled by two nameservers at
online4u.no. They are on different IP networks. Incoming mail for
fn.no is handled by two mailservers having a total of three IP numbers. All of them are on the same IP network.
fn.no has one IP number , but the reverse is
gw.hasas.no.
ilo.no point to the same IP and also shares nameservers.
www.fn.no,
gw.hasas.no,
tusenarsmalene.no and
flerkulturell-ressursbank.no point to the same IP.
o4u.no,
cte.no,
hasas.no,
hetra.no,
bzerk.no and at least 55 other hosts share nameservers with this domain.
tf.no,
nsf.no,
cip.no,
kns.no,
ntv.no and at least 56 other hosts share mailservers with this domain.
www.fn.no and
mail.fn.no are subdomains to this hostname.
fn.no is hosted on a server in Norway.
Reputation is not yet known.