Summary
fn.hu is a domain controlled by two nameservers on different IP networks. Incoming mail for
fn.hu is handled by one mailserver at
sanomaonline.hu.
fn.hu has one IP number , but the reverse is
fe02.ew.sanomabp.hu.
fhm.hu and
figyelo.hu point to the same IP and also shares both nameservers and mailservers.
focivb2006.hu point to the same IP and also shares mailservers.
www.fn.hu,
www.fhm.hu and
fe02.ew.sanomabp.hu point to the same IP.
mc.hu,
ekh.hu,
nlc.hu,
lap.hu,
polc.hu and at least 39 other hosts share both nameservers and mailservers with this domain.
exit.hu,
best.hu,
story.hu,
vnubp.hu,
tango.hu and at least 55 other hosts share nameservers with this domain.
nl.hu,
ng.hu,
nle.hu,
best.hu,
tv24.hu and at least 68 other hosts share mailservers with this domain.
www.fn.hu,
mail.fn.hu and
valkyre.fn.hu are subdomains to this hostname.
fn.hu is hosted on a server in Hungary.
Reputation is not yet known.